#!/usr/bin/env python
# coding: utf-8

from setuptools import setup

setup(
    name='pytoml',
    version='0.1.13',

    description='A parser for TOML-0.4.0',
    author='Martin Vejnár',
    author_email='avakar@ratatanek.cz',
    url='https://github.com/avakar/pytoml',
    license='MIT',

    packages=['pytoml'],
    )
